<?php

/*

Plugin Name: WP Graphix Magic Light

Plugin URI: http://www.wpgraphixmagic.com

Description: Add salespage graphics to your theme in seconds!

Version: 1.6.3

Author: Scott Inman

Author URI: http://www.wpgraphixmagic.com

*/



// Plugin root folder

$wpgfxm_base_dir = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));

 



// Load css for all shortcodes

function wpgfxm_shortcode_styles() 

{

	// The path to our root plugin folder

	global $wpgfxm_base_dir;

	wp_enqueue_style('wpgfxm-styles', $wpgfxm_base_dir . 'wpgfxm-general-styles.css');

}

add_action('wp_print_styles', 'wpgfxm_shortcode_styles');





// Adds fade effect to buttons

function wpgfxm_button_shortcodes_js() {

	global $wpgfxm_base_dir;

	wp_enqueue_script('fade-shortcode-buttons', $wpgfxm_base_dir . 'includes/js/button.fade.js', array('jquery'));

}

add_action('wp_print_scripts', 'wpgfxm_button_shortcodes_js');



// Load Google Fonts

function load_gfonts() {

            wp_register_style('googleFonts', 'http://fonts.googleapis.com/css?family=Ubuntu:400,500,700,500italic,700italic');

            wp_enqueue_style('googleFonts');

        }

 

add_action('wp_print_styles', 'load_gfonts');





// Enable shortcodes in widget areas

add_filter( 'widget_text', 'do_shortcode' );



// Enable shortcode nesting

add_filter('the_content', 'do_shortcode');



// Filters the tinyMCE buttons and adds our custom buttons

function wpgfxm_shortcode_buttons() {



	// Don't bother doing this stuff if the current user lacks permissions

	if ( ( current_user_can('edit_posts') || current_user_can('edit_pages') ) && get_user_option('rich_editing') == 'true') {



		// filter the tinyMCE buttons and add our own

		add_filter('mce_buttons_3', 'register_wpgfxm_buttons');

		add_filter('mce_external_plugins', 'add_wpgfxm_tinymce_plugin');

	}

}



// Init process for button control

add_action('init', 'wpgfxm_shortcode_buttons');



// Registers the buttons for use

function register_wpgfxm_buttons($buttons) {

	// "wpgfxm_button" is the CLASS of our button

	$buttons[] = 'wpgfxm_headlines';

    $buttons[] = 'wpgfxm_highlighter';

	$buttons[] = 'wpgfxm_dividers';

	$buttons[] = 'wpgfxm_bullets';

    $buttons[] = 'wpgfxm_contentboxes';

	$buttons[] = 'wpgfxm_button';

	$buttons[] = 'wpgfxm_salesbuttons';

    $buttons[] = 'wpgfxm_salesboxes';

	$buttons[] = 'wpgfxm_badge';

	$buttons[] = 'wpgfxm_fullversion';

	return $buttons;

}



// Add the button to the tinyMCE bar

function add_wpgfxm_tinymce_plugin($plugin_array) {

	global $wpgfxm_base_dir;

	$plugin_array['wpgfxm_headlines'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_highlighter'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_dividers'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_bullets'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_contentboxes'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_button'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_salesbuttons'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_salesboxes'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_badge'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	$plugin_array['wpgfxm_fullversion'] = $wpgfxm_base_dir . 'wp-graphix-magic.js';

	return $plugin_array;

}



include_once('includes/headlines/headlines-shortcodes.php');

include_once('includes/highlighter/highlighter-shortcodes.php');

include_once('includes/dividers/dividers-shortcodes.php');

include_once('includes/bullets/bullets-shortcodes.php');

include_once('includes/contentboxes/contentboxes-shortcodes.php');

include_once('includes/buttons/buttons-shortcodes.php');

include_once('includes/salesbuttons/salesbuttons-shortcodes.php');

include_once('includes/salesboxes/salesboxes-shortcodes.php');

include_once('includes/badges/badges-shortcodes.php');



@ini_set('pcre.backtrack_limit', 500000);



// Check for plugin updates

$api_url = 'http://update-light.wpgraphixmagic.com/api/';

$plugin_slug = basename(dirname(__FILE__));





// Take over the update check

add_filter('pre_set_site_transient_update_plugins', 'check_for_plugin_update');



function check_for_plugin_update($checked_data) {

	global $api_url, $plugin_slug;



	if (empty($checked_data->checked))

		return $checked_data;



	$request_args = array(

		'slug' => $plugin_slug,

		'version' => $checked_data->checked[$plugin_slug .'/'. $plugin_slug .'.php'],

	);



	$request_string = prepare_request('basic_check', $request_args);



	// Start checking for an update

	$raw_response = wp_remote_post($api_url, $request_string);



	if (!is_wp_error($raw_response) && ($raw_response['response']['code'] == 200))

		$response = unserialize($raw_response['body']);



	if (is_object($response) && !empty($response)) // Feed the update data into WP updater

		$checked_data->response[$plugin_slug .'/'. $plugin_slug .'.php'] = $response;



	return $checked_data;

}





// Take over the Plugin info screen

add_filter('plugins_api', 'my_plugin_api_call', 10, 3);



function my_plugin_api_call($def, $action, $args) {

	global $plugin_slug, $api_url;



	if ($args->slug != $plugin_slug)

		return false;



	// Get the current version

	$plugin_info = get_site_transient('update_plugins');

	$current_version = $plugin_info->checked[$plugin_slug .'/'. $plugin_slug .'.php'];

	$args->version = $current_version;



	$request_string = prepare_request($action, $args);



	$request = wp_remote_post($api_url, $request_string);



	if (is_wp_error($request)) {

		$res = new WP_Error('plugins_api_failed', __('An Unexpected HTTP Error occurred during the API request.</p> <p><a href="?" onclick="document.location.reload(); return false;">Try again</a>'), $request->get_error_message());

	} else {

		$res = unserialize($request['body']);



		if ($res === false)

			$res = new WP_Error('plugins_api_failed', __('An unknown error occurred'), $request['body']);

	}



	return $res;

}





function prepare_request($action, $args) {

	global $wp_version;



	return array(

		'body' => array(

			'action' => $action, 

			'request' => serialize($args),

			'api-key' => md5(get_bloginfo('url'))

		),

		'user-agent' => 'WordPress/' . $wp_version . '; ' . get_bloginfo('url')

	);	

}



?>